@@ -5,12 +5,10 @@
 
 #include "bits/print-bin.h"
 
-//#include "comb/composition-nz-rank.h"
-//#include "comb/comb-print.h"
-
 #include "fxttypes.h"
 #include "fxtio.h"
 #include "bits/bitsperlong.h"
+#include "bits/bitcount.h"
 
 #include "nextarg.h"
 #include "jjassert.h"
@@ -48,25 +46,25 @@ main(int argc, char **argv)
     do
     {
         ulong x = G.data();
+//        if ( 3 != bit_count( x ) )  continue;
+
         cout  << setw(4) << ct << ":";
         print_bin("    ", x, n);  // words of the Gray code
         print_bin("    ", x^xo, n);  // delta sequence
+
+//        print_bin("    ", ~x^1, n);  // complement
+//        cout << " " << bit_count( (~x^1)&((1UL<<n)-1) ) << ",";
+        // [5, 4, 3, 2, 1,] 0, 1, 2, 3, 2, 1, 2, 3, 4, 3, 2, 1, 2, 3, 2,
+        // 3, 4, 5, 4, 3, 2, 3, 4, 3, 2, 1, 2, 3, 4, 3, 2, 3, 4, 5, 4,
+        // 3, 4, 5, 6, 5, 4, 3, 4, 3, 2, 3, 4, 5, 4, 3, 2, 3, 4, 3, 2,
+        // 1, 2, 3, 4  A000000
+
         xo = x;
 //        print_bin("    ", G.tr_, n);  // internal data: track
-
-        ulong z = bin_to_sl_gray(ct, n);
-//        print_bin("    ", z, n);
-
-#if 0
-        ulong C[64];
-        ulong m = composition_nz_unrank(~x, C, n+1);
-        print_vec("    ", C, m);
-#endif
-
-        ++ct;
         cout << endl;
 
-        jjassert( x == z );
+        jjassert( x == bin_to_sl_gray( ct, n ) );
+        ++ct;
     }
     while ( G.next() );
 #endif  // TIMING
@@ -77,6 +75,17 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
+Timing: (Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz)
+GCC 12.2.0
+
+time ./bin 32
+arg 1: 32 == n  [n-bit binary words]  default=6
+ ct=4294967296
+6.04user 0.00system 0:06.04elapsed 100%CPU
+ ==> 2^32/6.04 == 711,087,300 per second
+
+
+
 Timing: (AMD Phenom II X4 945 3000MHz)
 
  time ./bin 32
