@@ -72,40 +72,48 @@ main(int argc, char **argv)
 
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
- time ./bin 32 20
+time ./bin 32 20
 arg 1: 32 == n  [Shifts combinations (n over k):  n  (n>0)]  default=7
-arg 2: 20 == k  [  (0<k<=n)]  default=4
-./bin 32 20  1.53s user 0.00s system 100% cpu 1.533 total
- ==> binomial(32, 20)/1.53 == 147,577,019 per second
-./bin 32 20  2.13s user 0.00s system 99% cpu 2.131 total  // with bit-scan
+arg 2: 20 == k  [  (0<=k<=n)]  default=4
+ ct=225792840
+0.44user 0.00system 0:00.44elapsed 100%CPU
+ ==> binomial(32, 20)/0.44 == 513,165,545 per second
 
 
- time ./bin 32 12
+time ./bin 32 12
 arg 1: 32 == n  [Shifts combinations (n over k):  n  (n>0)]  default=7
-arg 2: 12 == k  [  (0<k<=n)]  default=4
-./bin 32 12  1.01s user 0.00s system 99% cpu 1.020 total
- ==> binomial(32, 12)/1.01 == 223,557,267  per second
-./bin 32 12  1.16s user 0.00s system 99% cpu 1.164 total  // with bit-scan
+arg 2: 12 == k  [  (0<=k<=n)]  default=4
+ ct=225792840
+0.28user 0.00system 0:00.29elapsed 99%CPU
+ ==> binomial(32, 12)/0.28 == 806,403,000 per second
 
 
- time ./bin 60 7  # very sparse:
-./bin 60 7  0.93s user 0.00s system 99% cpu 0.936 total
- ==> binomial(60, 7)/0.93 == 415,276,258 per second
-./bin 60 7  0.91s user 0.00s system 100% cpu 0.915 total  // with bit-scan
+time ./bin 60 7  # very sparse:
+arg 1: 60 == n  [Shifts combinations (n over k):  n  (n>0)]  default=7
+arg 2: 7 == k  [  (0<=k<=n)]  default=4
+ ct=386206920
+0.29user 0.00system 0:00.29elapsed 100%CPU
+ ==> binomial(60, 7)/0.29 == 1,331,748,000 per second
 
 
- time ./bin 60 53  # very dense:
-./bin 60 53  3.48s user 0.02s system 99% cpu 3.503 total
- ==> binomial(60, 53)/3.48 == 110,979,000  per second
-./bin 60 53  5.91s user 0.00s system 100% cpu 5.910 total  // with bit-scan
+time ./bin 60 53  # very dense:
+arg 1: 60 == n  [Shifts combinations (n over k):  n  (n>0)]  default=7
+arg 2: 53 == k  [  (0<=k<=n)]  default=4
+ ct=386206920
+1.10user 0.00system 0:01.10elapsed 100%CPU
+ ==> binomial(60, 53)/1.10 == 351,097,200 per second
 
- time ./bin 33 16
+time ./bin 33 16
 arg 1: 33 == n  [Shifts combinations (n over k):  n  (n>0)]  default=7
 arg 2: 16 == k  [  (0<=k<=n)]  default=4
+ ct=1166803110
+1.83user 0.00system 0:01.83elapsed 100%CPU
+  ==> binomial(33,16)/1.83 == 637,597,327 per second
 ./bin 33 16  6.22s user 0.00s system 100% cpu 6.218 total
- ==> binomial(33, 16)/6.22 == 187,588,924 per second
+
 */
 
 /*
