@@ -18,7 +18,7 @@ main(int argc, char **argv)
 
     thue_morse S(k);
 
-#ifdef TIMING
+#if defined TIMING
     ulong x = 0;  // dummy
     for (ulong j=0; j<n; ++j)  x ^= S.next();
     cout << "dummy=" << x << endl;
