@@ -36,7 +36,7 @@ main(int argc, char **argv)
 
 
     ulong pq = 0;
-    NXARG(pq, "Whether do render paths (as ASCII art)");
+    NXARG(pq, "Whether do render paths as ASCII art (values 1 or 2)");
 
     const ulong *x = C.data();
     const ulong n2 = 2 * n;
@@ -81,8 +81,8 @@ main(int argc, char **argv)
         if ( pq )  // ASCII art
         {
             cout << endl;
-            if ( pq == 1 )  C.print_aa();
-            else            C.print_horiz_aa();
+            if ( pq == 1 )  C.print_horiz_aa();
+            else            C.print_vert_aa();
             cout << endl;
         }
 
