@@ -86,7 +86,7 @@ main(int argc, char **argv)
         ulong rgs2[32];
         // only one position changes at each step,
         // but in general by more than one unit.
-        // All changes are homogeneous
+        // All changes in the paren word are homogeneous.
         jjassert( paren_string_to_rgs(str, rgs2) );
         rgs_to_paren_string(rgs2, n, str2, true);
         jjassert( paren_string_to_rgs(str2, rgs2) );
@@ -115,6 +115,18 @@ main(int argc, char **argv)
 
 
 /*
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
+
+time ./bin 18 0
+arg 1: 18 == n  [Number of paren pairs]  default=5
+arg 2: 0 == dr0  [Whether to start with ()()()...(), else (((...)))]  default=1
+ ct=477638700
+1.10user 0.00system 0:01.10elapsed 100%CPU
+ ==> 477638700/1.10 == 434,217,000 per second
+
+
+
 Timing: (AMD Phenom II X4 945 3000MHz)
 
  time ./bin 18 0
