@@ -80,7 +80,7 @@ main(int argc, char **argv)
 
 //        cout << "    " << C.paren_string();
 
-#if 1  // show reversed paren-string and its RGS
+#if 0  // show reversed paren-string and its RGS
         reverse_paren_string(str, n2, str2);  // reversed string
         paren_string_to_rgs( str2, rgs2 );  // "reversed" RGS
         print_vec("    ", rgs2, n, true);
@@ -90,6 +90,11 @@ main(int argc, char **argv)
         jjassert( is_paren_string(str2, n2) );
 #endif
 
+        rgs_to_paren_string( C.data(), n, str2 );
+        cout << "    ";
+        for (ulong k=0; k<n2; ++k)  cout <<  str2[k];
+
+
         cout << endl;
 
         jjassert( C.OK() );
