@@ -17,6 +17,7 @@
 //% Lexicographic order.
 
 
+// Cf. comb/setpart-noncrossing-rgs-demo.cc
 // Cf. comb/catalan-rgs-demo.cc for Catalan RGS.
 
 
@@ -40,9 +41,8 @@ main(int argc, char **argv)
 #if !defined TIMING
         cout << setw(4) << ct << ":";
 
-        // print RGS:
-        C.print("  ", true );
-        print_vec("    ", P, n , true);
+        C.print("  ", true );  // Catalan RGS
+        print_vec("    ", P, n , true);  // stepart RGS
 
         print_setpart("    ", P, n, 0, 1);
 
@@ -67,6 +67,17 @@ main(int argc, char **argv)
 
 
 /*
+Timing: (Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz)
+GCC 12.2.0
+
+time ./bin 17
+arg 1: 17 == n  [Number of elements in set]  default=5
+ ct=129644790
+4.95user 0.00system 0:04.95elapsed 100%CPU
+ ==> 129644790/4.95 == 26,190,866 per second
+(rather slow!)
+
+
 Timing: (AMD Phenom II X4 945 3000MHz)
 
 GCC 4.9.1:
