@@ -30,7 +30,7 @@ main(int argc, char **argv)
 
     ulong ct = 0;
 
-#ifdef TIMING
+#if defined TIMING
     if ( 0==rq )  do  { ++ct; }  while ( k!=C.next() );
     else          do  { ++ct; }  while ( k!=C.prev() );
 
@@ -56,7 +56,7 @@ main(int argc, char **argv)
 
     cout << " ct = " << ct << endl;
 
-#ifndef TIMING
+#if !defined TIMING
     delete [] tt;
 #endif  // TIMING
 
