@@ -8,7 +8,9 @@
 #include "comb/comb-print.h"
 
 
-//% Strong minimal-change order for combinations (Chase's sequence) via endo steps
+//% Combinations (n choose k) in strong minimal-change order ("Chase's sequence").
+//% The set (as opposed to delta set) is generated.
+//% Generation via endo/enup counting.
 
 //#define TIMING  // uncomment to disable printing
 
@@ -29,11 +31,8 @@ main(int argc, char **argv)
         ++ct;
 #if !defined TIMING
         cout << setw(3) << ct << ":";
-        const ulong *x = C.data();
-        print_set("    ", x, k);
-        print_set_as_deltaset("    ", x, k, n);
-//        print_set("    s=", C.s_, k);
-//        print_set("    a=", C.a_, k);
+        C.print_set("    ");
+        C.print_deltaset("    ");
         cout << endl;
 #endif  // TIMING
         j = C.next();
@@ -48,21 +47,22 @@ main(int argc, char **argv)
 
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
  time ./bin 32 20
 arg 1: 32 == n  [Combinations (n choose k)]  default=8
 arg 2: 20 == k  [k elements at a time]  default=3
  ct = 225792840
-./bin 32 20  4.95s user 0.02s system 99% cpu 4.977 total
- ==> 225792840/4.95 == 45,614,715 per second
+1.26user 0.00system 0:01.26elapsed 100%CPU
+ ==> 225792840/1.26 == 179,200,666 per second
 
  time ./bin 32 12
 arg 1: 32 == n  [Combinations (n choose k)]  default=8
 arg 2: 12 == k  [k elements at a time]  default=3
  ct = 225792840
-./bin 32 12  3.80s user 0.02s system 99% cpu 3.830 total
- ==> 225792840/3.80 == 59,419,168 per second
+1.06user 0.00system 0:01.06elapsed 100%CPU
+ ==> 225792840/1.06 == 213,012,113 per second
 
 */
 
