@@ -2,7 +2,6 @@
 #include "comb/combination-revdoor.h"
 
 #include "aux0/binomial.h"
-#include "comb/comb-print.h"  // print_set_as_deltaset()
 
 #include "fxttypes.h"
 #include "jjassert.h"
@@ -10,7 +9,11 @@
 
 #include "fxtio.h"
 
-//% Generating all combinations in minimal-change order: revolving door algorithm.
+//% Combinations in a minimal-change order.
+//% Algorithm R, "revolving-door combinations", TAOCP 4A/1, pp.363.
+//%  W. H. Payne, F. M. Ives: "Combination Generators",
+//%  ACM Transactions on Mathematical Software (TOMS),
+//%  vol.5, no.2, pp.163-172, (June-1979).
 
 //#define TIMING  // uncomment to disable printing
 
@@ -32,7 +35,7 @@ main(int argc, char **argv)
     do
     {
 #if !defined TIMING
-        cout << setw(3) << ct << ":    ";
+        cout << setw(4) << ct << ":  ";
         C.print_set("  ");
         C.print_deltaset("    ");
         cout << endl;
@@ -42,7 +45,7 @@ main(int argc, char **argv)
     while ( C.next() );
 
     ulong bnk =  binomial(n, k);
-    cout << "binomial(" << n << ", " << k << ")=" << bnk << endl;
+    cout << "binomial(" << n << ", " << k << ")=" << bnk;
     jjassert( bnk==ct );
     cout << endl;
 
@@ -53,23 +56,37 @@ main(int argc, char **argv)
 // for n in $(seq 1 10); do for k in $(seq 1 $n); do ./bin $n $k || break 2; done; done
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
  time ./bin 32 20
-arg 1: 32 == n  [(n choose k): n>=1]  default=7
+arg 1: 32 == n  [Combination (n choose k) in minimal-change order: n>=1]  default=7
 arg 2: 20 == k  [(n choose k):  1<=k<=n]  default=4
-arg 3: 0 == rq  [Option: print in reverse order]  default=0
 binomial(32, 20)=225792840
-./bin 32 20  1.90s user 0.02s system 99% cpu 1.929 total
- ==> 225792840/1.90 == 118,838,336 per second
+0.39user 0.00system 0:00.39elapsed 100%CPU
+ ==> 225792840/0.39 == 578,956,000 per second
 
  time ./bin 32 12
-arg 1: 32 == n  [(n choose k): n>=1]  default=7
+arg 1: 32 == n  [Combination (n choose k) in minimal-change order: n>=1]  default=7
 arg 2: 12 == k  [(n choose k):  1<=k<=n]  default=4
-arg 3: 0 == rq  [Option: print in reverse order]  default=0
 binomial(32, 12)=225792840
-./bin 32 12  1.23s user 0.02s system 99% cpu 1.247 total
- ==> 225792840/1.23 == 183,571,414 per second
+0.23user 0.00system 0:00.23elapsed 100%CPU
+ ==> 225792840/0.23 == 981,708,000 per second
+
+
+ time ./bin 64 7
+arg 1: 64 == n  [Combination (n choose k) in minimal-change order: n>=1]  default=7
+arg 2: 7 == k  [(n choose k):  1<=k<=n]  default=4
+binomial(64, 7)=621216192
+0.50user 0.00system 0:00.50elapsed 100%CPU
+ ==> 621216192/0.50 == 1,242,432,384 per second
+
+ time ./bin 64 57
+arg 1: 64 == n  [Combination (n choose k) in minimal-change order: n>=1]  default=7
+arg 2: 57 == k  [(n choose k):  1<=k<=n]  default=4
+binomial(64, 57)=621216192
+2.70user 0.00system 0:02.70elapsed 100%CPU
+ ==> 621216192/2.70 == 230,080,071 per second
 
 */
 
