@@ -13,8 +13,11 @@
 #include "jjassert.h"
 
 
-//% Generating all compositions of n into k parts in co-lexicographic (colex) order.
-//% Algorithm efficient also with sparse case, i.e. k much greater than n.
+//% Generating all compositions of n into k parts
+//% in co-lexicographic (colex) order.
+//% Algorithm efficient also with sparse case, i.e., k much greater than n.
+
+// Cf. comb/composition-colex-demo.cc
 
 //#define TIMING  // uncomment to disable printing
 
@@ -75,30 +78,30 @@ main(int argc, char **argv)
 
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
-
- time ./bin 30 10 0
+ time ./bin 30 10
 arg 1: 30 == n  [Compositions of n (n>=1)]  default=3
 arg 2: 10 == k  [Into k parts  (k-compositions of n) (k>=1) ]  default=5
-  ct=211915132
-./bin 30 10 0  0.77s user 0.00s system 99% cpu 0.773 total
- ==> 211915132/0.77 == 275,214,457 per second
+ ct=211915132
+0.51user 0.00system 0:00.51elapsed 99%CPU
+ ==> 211915132/0.51 == 415,519,866 per second
 
- time ./bin 10 30 0
+ time ./bin 10 30
 arg 1: 10 == n  [Compositions of n (n>=1)]  default=3
 arg 2: 30 == k  [Into k parts  (k-compositions of n) (k>=1) ]  default=5
-  ct=635745396
-./bin 10 30 0  2.31s user 0.00s system 100% cpu 2.311 total
- ==> 635745396/2.31 == 275,214,457 per second
+ ct=635745396
+1.56user 0.00system 0:01.56elapsed 100%CPU
+ ==> 635745396/1.56 == 407,529,100 per second
 
 // very sparse case:
  time ./bin 5 100
 arg 1: 5 == n  [Compositions of n (n>=1)]  default=3
 arg 2: 100 == k  [Into k parts  (k-compositions of n) (k>=1) ]  default=5
-  ct=91962520
-./bin 5 100  0.34s user 0.00s system 94% cpu 0.358 total
- ==> 91962520/0.34 == 270,478,000 per second
+ ct=91962520
+0.22user 0.00system 0:00.22elapsed 99%CPU
+ ==> 91962520/0.22 == 418,011,454 per second
 
 
 */
@@ -106,7 +109,6 @@ arg 2: 100 == k  [Into k parts  (k-compositions of n) (k>=1) ]  default=5
 /*
 Timing: (AMD Phenom II X4 945 3000MHz)
 
-
  time ./bin 30 10 0
   ct=211915132
 ./bin 30 10 0  0.56s user 0.00s system 99% cpu 0.565 total
