@@ -106,8 +106,25 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing: (AMD Phenom II X4 945 3000MHz)
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
+time ./bin 31
+arg 1: 31 == n  [compositions of n]  default=7
+ ct=1073741824
+2.39user 0.00system 0:02.40elapsed 99%CPU
+ ==> 1073741824/2.39 == 449,264,361 per second
+
+time ./bin 31
+arg 1: 31 == n  [compositions of n]  default=7
+COMPOSITION_NZ_GRAY2_FIXARRAYS defined.
+ ct=1073741824
+2.09user 0.00system 0:02.09elapsed 100%CPU
+ ==> 1073741824/2.09 == 513,752,068 per second
+
+
+
+Timing: (AMD Phenom II X4 945 3000MHz)
 GCC 4.9.0:
 
  time ./bin 31
