@@ -63,13 +63,16 @@ bool cond_odd(const ulong *a, ulong k)
 // Compositions into odd parts:
 // A000045 (Fibonacci numbers).
 {
-    return  ( 1 == ( a[k] & 1UL ) );
+    if ( 0 == ( a[k] & 1UL ) )  return false;
 //    return ( a[k] <= 2 );  // also Fibonacci
 //    return ( a[k] >= 2 );  // also Fibonacci (A212804)
+    if ( k == 0 )  return true;
+    if ( a[k] > a[0] )  return false;  // A368746
+//    if ( a[k] >= a[0] )  return false;  // essentially the same
+    return true;
 }
 // -------------------------
 
-
 bool cond_smooth(const ulong *a, ulong k)
 // Absolute differences <= 1:  A034297.
 {
@@ -272,7 +275,9 @@ bool cond_mers_desc(const ulong *a, ulong k)
 // s-partitions: partitions into Mersenne numbers: A000929
 {
     ulong x = a[k];
-    if ( !!(x & (x+1)) )  return false;
+    ulong y = x + 1;
+    y &= (y-1);
+    if ( y != 0 )  return false;
     if ( k==0 )  return true;
     return ( x<=a[k-1] );
 }
@@ -283,7 +288,9 @@ bool cond_mers(const ulong *a, ulong k)
 // parts are Mersenne numbers: A104977 (absolute values)
 {
     ulong x = a[k];
-    return !(x & (x+1));
+    x += 1;
+    x &= (x-1);
+    return ( x == 0 );
 }
 // -------------------------
 
@@ -297,6 +304,14 @@ bool cond_2pow(const ulong *a, ulong k)
 // -------------------------
 
 
+bool cond_first_even(const ulong *a, ulong k)
+{
+    if ( k == 0 )  return ( a[0] & 1 ) == 0;
+    return ( a[k] <= a[0]/2 );
+    return true;
+}
+// -------------------------
+
 bool cond_first_max(const ulong *a, ulong k)
 {
     if ( k==0 )  return true;
@@ -360,11 +375,12 @@ bool cond_up_step(const ulong *a, ulong k)
 
 bool cond_test(const ulong *a, ulong k)
 {
-    if ( k==0 )  return true;
-
-    return ( a[k-1] < 2*a[k] ); // A274199
+    if ( 0==(k & 1) )  return ( a[k] == 1 ); // A000045, 2024-January-05
+//    if ( 1==(k & 1) )  return ( a[k] == 1 ); // A000045
+//    if ( k <= 1 )  return ( a[k] != 1 );
+//    if ( k == 0 )  return true;
+//    return ( a[k-1] < 2*a[k] ); // A274199
 //    return ( ( a[k] <= 2*a[k-1] ) && ( a[k-1] <= 2*a[k] ) ); // A224957
-
 //    return ( ( a[k] == 2*a[k-1] ) || ( a[k-1] == 2*a[k] ) ); // A342331
 //    return ( ( a[k] > 2*a[k-1] ) || ( a[k-1] > 2*a[k] ) ); // A342332
 //    return ( ( a[k] >= 2*a[k-1] ) || ( a[k-1] >= 2*a[k] ) ); // A342333
@@ -377,6 +393,17 @@ bool cond_test(const ulong *a, ulong k)
 }
 // -------------------------
 
+bool cond_arndt(const ulong *a, ulong k)
+// Compositions of n where there is a drop between every second
+//   pair of parts, starting with the first and second part.
+{
+//    if ( k!=0 )  if ( a[k]>a[k-1] )  return false;  // partitions: A000726
+    if ( (k & 1) == 0 )  return true;
+    return ( a[k-1] > a[k] );  // A000045
+//    return ( a[k-1] >= a[k] );  // A028495
+}
+// -------------------------
+
 //  echo $(for n in $(seq 1 20); do ./bin $n 99; done | grep ct= ) | sed 's/ ct=/, /g;'
 
 
@@ -387,6 +414,7 @@ main(int argc, char **argv)
     NXARG(n, "compositions of n (n>=1)");
 
     ulong c = 5;
+//    ulong c = 31;
     NXARG(c, "Condition function:"
           "\n      0 ==> all compositions (condition always true),"
           "\n      1 ==> adjacent digits distinct"
@@ -404,55 +432,60 @@ main(int argc, char **argv)
 
     composition_nz_prefix_cond P(n);
 
+#define DOIT( CC )  cout << "Predicate " << c << " := " << #CC << "\n"; P.first( CC );
     switch ( c )
     {
-    case 0: P.first( cond_true );  break;
-    case 1: P.first( cond_dist );  break;
-    case 2: P.first( cond_updown );  break;
-    case 3: P.first( cond_consec );  break;
-    case 4: P.first( cond_odd );  break;
-    case 5: P.first( cond_growth );  break;
-    case 6: P.first( cond_fall );  break;
-    case 7: P.first( cond_mers );  break;
-    case 8: P.first( cond_mers_desc );  break;
-    case 9: P.first( cond_2pow );  break;
+    case 0: DOIT( cond_true );  break;
+    case 1: DOIT( cond_dist );  break;
+    case 2: DOIT( cond_updown );  break;
+    case 3: DOIT( cond_consec );  break;
+    case 4: DOIT( cond_odd );  break;
+    case 5: DOIT( cond_growth );  break;
+    case 6: DOIT( cond_fall );  break;
+    case 7: DOIT( cond_mers );  break;
+    case 8: DOIT( cond_mers_desc );  break;
+    case 9: DOIT( cond_2pow );  break;
 
 
-    case 20: P.first( cond_change );  break;
-    case 22: P.first( cond_2dist );  break;
+    case 20: DOIT( cond_change );  break;
+    case 22: DOIT( cond_2dist );  break;
 
-    case 33: P.first( cond_no_3prog );  break;
+    case 30: DOIT( cond_arndt );  break;
 
-    case 40: P.first( cond_par_diff );  break;
 
-    case 45: P.first( cond_first_max );  break;
-    case 46: P.first( cond_first_min );  break;
-    case 47: P.first( cond_min );  break;
+    case 40: DOIT( cond_par_diff );  break;
 
-    case 50: P.first( cond_asc );  break;
-    case 51: P.first( cond_desc );  break;
+    case 45: DOIT( cond_first_max );  break;
+    case 46: DOIT( cond_first_min );  break;
+    case 47: DOIT( cond_min );  break;
+    case 48: DOIT( cond_first_even );  break;
 
-    case 55: P.first( cond_up_step );  break;
+    case 50: DOIT( cond_asc );  break;
+    case 51: DOIT( cond_desc );  break;
 
-    case 60: P.first( cond_smooth );  break;
-    case 61: P.first( cond_smooth_part );  break;
+    case 55: DOIT( cond_up_step );  break;
 
-    case 65: P.first( cond_1diff );  break;
-    case 66: P.first( cond_diff_growth );  break;
+    case 37: DOIT( cond_no_3prog );  break;
 
-    case 70: P.first( cond_superdiag );  break;
-    case 71: P.first( cond_subdiag );  break;
-    case 72: P.first( cond_superdiag_growth );  break;
-    case 73: P.first( cond_subdiag_growth );  break;
+    case 60: DOIT( cond_smooth );  break;
+    case 61: DOIT( cond_smooth_part );  break;
 
-    case 88: P.first( cond_false );  break;
+    case 65: DOIT( cond_1diff );  break;
+    case 66: DOIT( cond_diff_growth );  break;
 
-    case 91: P.first( cond_wiggly1 );  break;
-    case 92: P.first( cond_wiggly2 );  break;
+    case 70: DOIT( cond_superdiag );  break;
+    case 71: DOIT( cond_subdiag );  break;
+    case 72: DOIT( cond_superdiag_growth );  break;
+    case 73: DOIT( cond_subdiag_growth );  break;
 
-    case 95: P.first( cond_diff_neq1 );  break;
+    case 88: DOIT( cond_false );  break;
 
-    case 99: P.first( cond_test );  break;
+    case 91: DOIT( cond_wiggly1 );  break;
+    case 92: DOIT( cond_wiggly2 );  break;
+
+    case 95: DOIT( cond_diff_neq1 );  break;
+
+    case 99: DOIT( cond_test );  break;
 
 
     default:  cout << "Not a valid condition!" << endl;
@@ -462,7 +495,6 @@ main(int argc, char **argv)
     ulong ct = 0;
 
 #if defined TIMING
-    P.first( cond_test );
     while ( P.valid() )  { ++ct;  P.next(); }
 
 #else  // TIMING
@@ -479,7 +511,7 @@ main(int argc, char **argv)
         cout << setfill(' ');
         cout << ":";
 #else
-        cout << setw(2) << ct << ":";
+        cout << setw(4) << ct << ":";
 //        ulong m = P.num_parts();
 //        cout << "  [" << setw(2) << m << "]";
 #endif
