@@ -16,6 +16,7 @@
 
 // Cf. comb/perm1-prefix-cond-demo.cc for permutations with restricted prefixes.
 
+static ulong n; // make visible for condition functions
 
 //#define TIMING  // uncomment to disable printing
 
@@ -488,6 +489,36 @@ bool cond_leq_23(const ulong *a, ulong k)
 
 bool cond_test(const ulong *a, ulong k)  // last arg = 99
 {
+
+    // A333647 (one leading 1 less, we are looking at internal levels)
+    if ( k == 0 )
+    {
+        if ( n==1 ) return ( a[k] == 0 );
+        return ( a[k] <= 1 );
+    }
+
+    {
+        const long ar = (long)a[k-0];
+        const long a0 = (long)a[k-1];
+        const long al = (long)( k == 1 ? 0 : a[k-2] );
+        const long dd = al - 2*a0 + ar;
+        const long u = ( dd > 0 ? dd : -dd );
+        if ( u > 1 )  return false;
+    }
+
+    if ( k + 1 == n )
+    {
+        if ( a[k] > 1 )  return false;
+        const long ar = 0;  // == a[k+1]
+        const long a0 = (long)a[k-0];
+        const long al = (long)a[k-1];
+        const long dd = al - 2*a0 + ar;
+        const long u = ( dd > 0 ? dd : -dd );
+        if ( u > 1 )  return false;
+    }
+
+    return true;
+#if 0
     // A328357 with rfact:  (only for n >= 2)
     // implicit 0==a[-1] <= a[0]
 
@@ -509,16 +540,15 @@ bool cond_test(const ulong *a, ulong k)  // last arg = 99
             if ( a[0] <= a[1] )  return false;
         }
     }
-
     return true;
+#endif
 }
 // -------------------------
 
-
 int
 main(int argc, char **argv)
 {
-    ulong n = 4;
+    n = 4;
     NXARG(n, "Number of digits");
 
     ulong rr = 1;
@@ -546,63 +576,63 @@ main(int argc, char **argv)
 //          "\n      rest ==> see source"
           );
 
-
+#define DOIT( CC )  cout << "Predicate " << c << " := " << #CC << "\n"; M.first( CC );
     switch ( c )
     {
-    case 0: M.first( cond_true );  break;
-    case 1: M.first( cond_nonadj );  break;
-    case 2: M.first( cond_dist );  break;
-    case 3: M.first( cond_sorted );  break;
-    case 4: M.first( cond_smooth );  break;
-    case 5: M.first( cond_par );  break;
+    case 0: DOIT( cond_true );  break;
+    case 1: DOIT( cond_nonadj );  break;
+    case 2: DOIT( cond_dist );  break;
+    case 3: DOIT( cond_sorted );  break;
+    case 4: DOIT( cond_smooth );  break;
+    case 5: DOIT( cond_par );  break;
 
 
-    case 11: M.first( cond_dist_smooth );  break;
-    case 12: M.first( cond_dist2 );  break;
-    case 13: M.first( cond_sorted_full );  break;
-    case 14: M.first( cond_ccf_map );  break;
+    case 11: DOIT( cond_dist_smooth );  break;
+    case 12: DOIT( cond_dist2 );  break;
+    case 13: DOIT( cond_sorted_full );  break;
+    case 14: DOIT( cond_ccf_map );  break;
 
-    case 15: M.first( cond_ascent );  break;
-    case 16: M.first( cond_aj_neq_akp1 );  break;
-    case 17: M.first( cond_descent );  break;
-    case 18: M.first( cond_change );  break;
-    case 19: M.first( cond_eq );  break;
+    case 15: DOIT( cond_ascent );  break;
+    case 16: DOIT( cond_aj_neq_akp1 );  break;
+    case 17: DOIT( cond_descent );  break;
+    case 18: DOIT( cond_change );  break;
+    case 19: DOIT( cond_eq );  break;
 
-    case 20: M.first( cond_invol_fp );  break;
-    case 21: M.first( cond_zero_map_s );  break;
+    case 20: DOIT( cond_invol_fp );  break;
+    case 21: DOIT( cond_zero_map_s );  break;
 
-    case 22: M.first( cond_fp_ptr );  break;
+    case 22: DOIT( cond_fp_ptr );  break;
 
 
-    case 30: M.first( cond_arrange );  break;
-    case 31: M.first( cond_arrange1 );  break;
-    case 32: M.first( cond_arrange2 );  break;
+    case 30: DOIT( cond_arrange );  break;
+    case 31: DOIT( cond_arrange1 );  break;
+    case 32: DOIT( cond_arrange2 );  break;
 
-    case 40: M.first( cond_perm );  break;
-    case 41: M.first( cond_perm_ncyc );  break;
+    case 40: DOIT( cond_perm );  break;
+    case 41: DOIT( cond_perm_ncyc );  break;
 
-    case 50: M.first( cond_sorted_desc );  break;
+    case 50: DOIT( cond_sorted_desc );  break;
 
-    case 60: M.first( cond_pref_sum );  break;
+    case 60: DOIT( cond_pref_sum );  break;
 
-    case 70: M.first( cond_upstep );  break;
+    case 70: DOIT( cond_upstep );  break;
 
-    case 90: M.first( cond_setpart0 );  break;
-    case 91: M.first( cond_setpart );  break;
-    case 92: M.first( cond_setpart2 );  break;
-    case 93: M.first( cond_setpart3 );  break;
+    case 90: DOIT( cond_setpart0 );  break;
+    case 91: DOIT( cond_setpart );  break;
+    case 92: DOIT( cond_setpart2 );  break;
+    case 93: DOIT( cond_setpart3 );  break;
 
-    case 99: M.first( cond_test );  break;
+    case 99: DOIT( cond_test );  break;
 
-    case 110: M.first( cond_12_dist );  break;
+    case 110: DOIT( cond_12_dist );  break;
 
-    case 120: M.first( cond_leq_23 );  break;
+    case 120: DOIT( cond_leq_23 );  break;
 
-    case 130: M.first( cond_pref_fixedpoints );  break;
+    case 130: DOIT( cond_pref_fixedpoints );  break;
 
-    case 150: M.first( cond_total_ascent );  break;
+    case 150: DOIT( cond_total_ascent );  break;
 
-    default: M.first( cond_true );  break;
+    default: DOIT( cond_true );  break;
     }
 
     cout << endl;
