@@ -2,6 +2,7 @@
 #include "comb/mset-perm-gray.h"
 
 #include "comb/comb-print.h"
+#include "comb/fact2perm.h"
 
 #include "fxttypes.h"
 #include "fxtio.h"
@@ -28,7 +29,8 @@ main(int argc, char **argv)
     cout << "args: multiplicities of elements" << endl;
     if ( argc <= 1 )
     {
-        ulong t[]={2, 2, 1, 0};  // proper multisets  ct=30
+        ulong t[]={3, 2, 1, 0};  // proper multisets  ct=60
+//        ulong t[]={2, 2, 1, 0};  // proper multisets  ct=30
 //        ulong t[]={2, 2, 2, 0};  // proper multisets  ct=90
 //        ulong t[]={1, 1, 1, 1, 0};  // permutations  ct = 24
 //        ulong t[]={6, 2, 0};  // combinations  ct=28
@@ -48,11 +50,12 @@ main(int argc, char **argv)
     }
 
     mset_perm_gray P(r, k);
+    const ulong n = P.get_n();
 
     cout << "multiplicities: ( ";
-    for (ulong i=0; i<k; ++i)  cout << P.r_[i] << (i<k-1?", ":" ");
+    for (ulong i=0; i<k; ++i)  cout << r[i] << (i<k-1?", ":" ");
     cout << ")";
-    cout << "  k=" << P.k_ << "  n=" << P.n_;
+    cout << "  k=" << k << "  n=" << n;
     cout << endl;
 
     ulong ct = 0;
@@ -67,33 +70,23 @@ main(int argc, char **argv)
 
 #else  // TIMING
 
-    const bool dfz = true;  // whether to print dots for zeros
-    const ulong n = P.n_;
-
-    const ulong *x = P.data();
-
+//    ulong F[n];
     do
     {
         ++ct;
         cout << setw(4) << ct << ":";
 
 #if !defined DETAILS
-        print_perm("  ", x, n, dfz);
+        P.print("  ");
+//        perm2ffact( P.data_perm(), n, F);
+//        print_vec( "    ", F, n-1, true );
 #else  // DETAILS
-        { const ulong nn = n + 4;
-            print_perm("  ms=", P.ms_, nn, dfz);
-            print_perm("  P=", P.P_, nn, dfz);
-            print_perm("  Q=", P.Q_, nn, dfz);
-            cout << "  D=[";
-            for (ulong j=0; j<nn; ++j)
-            {
-                ulong d = P.D_[j];
-                cout << " ";
-                if ( (long)d < 0 )  cout << '-';
-                if ( (long)d > 0 )  cout << '+';
-                if ( d==0 )  cout << '.';
-            }
-            cout << " ]";
+        {
+//            const ulong nn = n + 4;
+            P.print("  ms=");
+            P.print_perm("  P=");
+            P.print_inv_perm("  Q=");
+            P.print_dirs("  D=");
         }
 #endif  // DETAILS
         if ( ct>1 )
@@ -119,35 +112,36 @@ main(int argc, char **argv)
 
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
- time ./bin 2 2 2 3 3 3
+time ./bin 2 2 2 3 3 3
 args: multiplicities of elements
 multiplicities: ( 2, 2, 2, 3, 3, 3 )  k=6  n=15
-ct=756756000
-./bin 2 2 2 3 3 3  19.80s user 0.03s system 100% cpu 19.821 total
- ==> 756756000/19.80 == 38,220,000 per second
+ ct=756756000
+8.00user 0.00system 0:08.00elapsed 100%CPU
+ ==> 756756000/8.00 == 94,594,500 per second
 
- time ./bin 3 3 3 2 2 2 ## reordered
+time ./bin 3 3 3 2 2 2 ## reordered
 args: multiplicities of elements
 multiplicities: ( 3, 3, 3, 2, 2, 2 )  k=6  n=15
-ct=756756000
-./bin 3 3 3 2 2 2  20.37s user 0.04s system 100% cpu 20.399 total
- ==> 756756000/20.37 == 37,150,515 per second
+ ct=756756000
+8.34user 0.00system 0:08.34elapsed 100%CPU
+ ==> 756756000/8.34 == 90,738,129 per second
 
- time ./bin 1 1 1 1 1 1 1 1 1 1 1 1  ## permutations of 12
+time ./bin 1 1 1 1 1 1 1 1 1 1 1 1  ## permutations of 12
 args: multiplicities of elements
 multiplicities: ( 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 )  k=12  n=12
-ct=479001600
-./bin 1 1 1 1 1 1 1 1 1 1 1 1  11.24s user 0.03s system 100% cpu 11.272 total
- ==> 479001600/11.24 == 42,615,800 per second
+ ct=479001600
+4.68user 0.00system 0:04.68elapsed 100%CPU
+ ==> 479001600/4.68 == 102,350,769 per second
 
- time ./bin 15 15  ## combination (30 choose 15)
+time ./bin 15 15  ## combination (30 choose 15)
 args: multiplicities of elements
 multiplicities: ( 15, 15 )  k=2  n=30
-ct=155117520
-./bin 15 15  5.75s user 0.00s system 99% cpu 5.757 total
- ==> 155117520/5.75 == 26,976,960 per second
+ ct=155117520
+2.07user 0.00system 0:02.07elapsed 100%CPU
+ ==> 155117520/2.07 == 74,936,000 per second
 
 */
 
