@@ -56,7 +56,7 @@ main(int argc, char **argv)
 
     ulong ct = 0;
 
-#ifdef TIMING
+#if defined TIMING
     do  { ++ct; }  while ( n != P.next() );
 
 #else  // TIMING
