@@ -51,16 +51,18 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
-  time ./bin 18
+time ./bin 18
 arg 1: 18 == n  [Number of parentheses pairs]  default=5
  ct = 477638700
-./bin 18  5.84s user 0.01s system 99% cpu 5.862 total
- ==> 477638700/5.84 == 81,787,448 per second
+3.61user 0.00system 0:03.61elapsed 100%CPU
+ ==> 477638700/3.61 == 132,309,889 per second
 
 
 Timing: (AMD Phenom II X4 945 3000MHz)
+
  time ./bin 18
 arg 1: 18 == n  [Number of parentheses pairs]  default=5
  ct = 477638700
