@@ -483,7 +483,7 @@ main(int argc, char **argv)
         st[ s ] += 1;
 
 
-#ifndef TIMING
+#if !defined TIMING
         cout << setw(4) << ct << ":";
         P.print("  ");
         cout << setw(4) << s;
