@@ -89,17 +89,21 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
+
  time ./bin 12
+ arg 1: 12 == n  [Number of elements to permute, n > 0]  default=4
  ct=479001600
-./bin 12  3.59s user 0.01s system 99% cpu 3.605 total
- ==> 479001600/3.59 == 133,426,629 per second
+0.93user 0.00system 0:00.93elapsed 100%CPU
+ ==> 479001600/0.93 == 515,055,483 per second
 
 no swaps:
  time ./bin 12
+ arg 1: 12 == n  [Number of elements to permute, n > 0]  default=4
  ct=479001600
-./bin 12  2.22s user 0.00s system 99% cpu 2.229 total
- ==> 479001600/2.22 == 215,766,486 per second
+0.81user 0.00system 0:00.81elapsed 100%CPU
+ ==> 479001600/0.81 == 591,360,000 per second
 
 */
 
