@@ -93,18 +93,23 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
- time ./bin 13
+time ./bin 13
+arg 1: 13 == n  [Number of elements to permute, n > 0]  default=4
 PERM_HEAP2_FIXARRAYS is defined.
-./bin 13  13.53s user 0.03s system 99% cpu 13.561 total
- ==> 13!/13.53 == 460,238,048 per second
+ ct=6227020800
+8.06user 0.00system 0:08.08elapsed 99%CPU
+ ==> 13!/8.06 == 772,583,225 per second
  ==> 4.78 cycles per update
 
- time ./bin 13
-./bin 13  22.21s user 0.04s system 100% cpu 22.245 total
- ==> 13!/22.21 == 280,370,139 per second
- ==> 7.85 cycles per update
+time ./bin 13
+arg 1: 13 == n  [Number of elements to permute, n > 0]  default=4
+ ct=6227020800
+11.79user 0.00system 0:11.79elapsed 100%CPU
+ ==> 13!/11.79 == 528,161,221 per second
+ ==> 7.00 cycles per update
 
 */
 
