@@ -35,12 +35,10 @@ main(int argc, char **argv)
     cout << "PERM_HEAP2_SWAPS_FIXARRAYS is defined" << endl;
 #endif
 
-    ulong zz = 0;
-    do  { zz^=(P.sw1_^P.sw2_); }  while ( P.next()!=n );
-
+    ulong dummy = 0;
+    do  { dummy^=(P.sw1_^P.sw2_); }  while ( P.next()!=n );
     cout << " ct=" << factorial(n) << endl;
-
-    return (zz==999);  // will return 0 because zz <= n
+    return (dummy==999);  // will return 0 because dummy <= n
 
 #else  // TIMING
 
@@ -89,17 +87,23 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
 fix-arrays, and XOR-ing sw1 and sw2:
- time ./bin 13
-./bin 13  17.39s user 0.04s system 100% cpu 17.429 total
- ==> 13!/17.39 == 358,080,552 per second
+time ./bin 13
+arg 1: 13 == n  [Number of elements to permute n>0]  default=4
+PERM_HEAP2_SWAPS_FIXARRAYS is defined
+ ct=6227020800
+9.42user 0.00system 0:09.42elapsed 100%CPU
+ ==> 13!/9.42 == 661,042,547 per second
 
 pointers, and XOR-ing sw1 and sw2:
- time ./bin 13
-./bin 13  19.40s user 0.03s system 100% cpu 19.425 total
- ==> 13!/19.40 == 320,980,453 per second
+time ./bin 13
+arg 1: 13 == n  [Number of elements to permute n>0]  default=4
+ ct=6227020800
+8.05user 0.00system 0:08.05elapsed 99%CPU
+ ==> 13!/8.05 == 773,542,956 per second
 */
 
 
@@ -121,7 +125,7 @@ arg 1: 13 == n  [Number of elements to permute n>0]  default=4
 
 */
 
- /*
+/*
 BENCHARGS=13
 */
 
