@@ -1,7 +1,7 @@
 
 #include "comb/perm-involution.h"
 
-#include "perm/permq.h"
+#include "perm/permq.h"  // perm_is_involution()
 #include "comb/comb-print.h"
 #include "perm/printcycles.h"
 
@@ -67,7 +67,7 @@ main(int argc, char **argv)
 
         cout << endl;
 
-        jjassert( is_involution(x, n) );
+        jjassert( perm_is_involution(x, n) );
 #endif
     }
     while ( P.next() );
