@@ -83,13 +83,15 @@ main(int argc, char **argv)
 
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
- time ./bin 12
+time ./bin 12
 arg 1: 12 == n  [Permutations of n elements (n>=2).]  default=4
-  ct=479001600
-./bin 12  2.28s user 0.00s system 99% cpu 2.290 total
- ==> 12!/2.28 == 210,088,421 per second
+PERM_MV0_UPDATE_D0 is defined.
+ ct=479001600
+2.18user 0.00system 0:02.18elapsed 100%CPU
+ ==> 12!/2.18 == 219,725,504 per second
 
 */
 
