@@ -18,12 +18,11 @@
 //#include "perm/perminvert.h"
 
 
-//% Permutations by prefix reversals, CAT algorithm.
+//% Permutations by reversing prefixes, CAT algorithm via prefix reversals.
 
 //#define TIMING  // uncomment to disable printing
 
 
-
 int
 main(int argc, char **argv)
 {
@@ -61,10 +60,11 @@ main(int argc, char **argv)
     {
         cout << setw(4) << ct << ":";
         P.print("    ", dfz);
-        print_mixedradix("    ", P.d_, n-1, dfz);
 
         make_inverse(x, t1, n);
-        print_perm("        ", t1, n, dfz);
+        print_perm("    ", t1, n, dfz);
+
+        print_mixedradix("    ", P.d_, n-1, dfz);
 
         if ( ct<nfh )
         {
@@ -94,13 +94,13 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
  time ./bin 12
-arg 1: 12 == n  [Number of elements to permute]  default=4
- ct=479001600
-./bin 12  3.39s user 0.05s system 100% cpu 3.439 total
- ==> 479001600/3.39 == 141,298,407 per second
+arg 1: 12 == n  [Number of elements to permute n>0]  default=4
+1.03user 0.00system 0:01.03elapsed 100%CPU
+ ==> 12!/1.03 == 465,050,097 per second
 
 */
 
