@@ -3,7 +3,7 @@
 #include "perm/perminvert.h"
 // demo-include "perm/perminvert.cc"
 
-#include "perm/permq.h"
+#include "perm/permq.h"  // perm_is_derangement()
 
 #include "comb/comb-print.h"
 
@@ -64,7 +64,7 @@ main(int argc, char **argv)
 
         if ( ct>0 )
         {
-            if ( !is_derangement(x, t, n) )  { cout << " N"; ++ndt; }
+            if ( ! perm_is_derangement(x, t, n) )  { cout << " N"; ++ndt; }
         }
         for (ulong j=0; j<n; ++j)  t[j] = x[j];  // last perm in t[]
 
