@@ -10,7 +10,7 @@
 
 //#include "comb/mixedradix-gray.h"
 
-#include "perm/permq.h"
+#include "perm/permq.h"  // perm_is_derangement()
 
 #include "comb/comb-print.h"
 
@@ -83,7 +83,7 @@ main(int argc, char **argv)
 
         if ( ct>0 )
         {
-            if ( !is_derangement(x, t, n) )
+            if ( ! perm_is_derangement(x, t, n) )
             {
                 cout << " N";
                 ++ndt;
