@@ -13,7 +13,9 @@
 #include "fxtio.h"
 
 
-//% Generate all permutations in star-transposition order.
+//% Permutations in star-transposition order (a Gray code).
+//% Algorithm by Gideon Ehrlich, as given by Knuth,
+//%  TAOCP 4A/1, Algorithm E "Ehrlich swaps", p.337.
 
 //#define TIMING  // uncomment to disable printing
 
@@ -37,7 +39,8 @@ main(int argc, char **argv)
     cout << "PERM_STAR_WITH_INVERSE is defined." << endl;
 #endif
     while ( P.next() )  {;}
-
+    ulong dummy = P.data()[0];
+    if ( dummy > n )  { return 1; }  // never
 #else  // TIMING
 
     ulong *fc = new ulong[n-1];
@@ -54,6 +57,7 @@ main(int argc, char **argv)
         ++ct;
 
         P.print("    ", dfz);
+        // right element in swap gives OEIS sequence A123400
         cout << "    (" << 0 << ", " << P.get_swap() << ") ";
         P.print_inv("    ", dfz);
 
@@ -84,31 +88,32 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
-% time ./bin 12
+time ./bin 12
 arg 1: 12 == n  [Number of elements to permute (n>=1)]  default=4
 PERM_STAR_FIXARRAYS is defined.
 PERM_STAR_WITH_INVERSE is defined.
-./bin 12  2.53s user 0.00s system 99% cpu 2.534 total
- ==> 12!/2.53 == 189,328,695 per second
+1.06user 0.00system 0:01.06elapsed 100%CPU
+ ==> 12!/1.06 == 451,888,301 per second
 
-% time ./bin 12
+time ./bin 12
 arg 1: 12 == n  [Number of elements to permute (n>=1)]  default=4
 PERM_STAR_FIXARRAYS is defined.
-./bin 12  2.54s user 0.00s system 100% cpu 2.534 total
- ==> 12!/2.54 == 188,583,307 per second
+1.12user 0.00system 0:01.13elapsed 99%CPU
+ ==> 12!/1.12 == 427,680,000 per second
 
-% time ./bin 12
+time ./bin 12
 arg 1: 12 == n  [Number of elements to permute (n>=1)]  default=4
 PERM_STAR_WITH_INVERSE is defined.
-./bin 12  5.36s user 0.00s system 99% cpu 5.370 total
- ==> 12!/5.36 == 89,365,970 per second
+1.37user 0.00system 0:01.37elapsed 99%CPU
+ ==> 12!/1.37 == 349,636,204 per second
 
-% time ./bin 12
+time ./bin 12
 arg 1: 12 == n  [Number of elements to permute (n>=1)]  default=4
-./bin 12  3.40s user 0.00s system 99% cpu 3.406 total
- ==> 12!/3.40 == 140,882,823 per second
+0.91user 0.00system 0:00.91elapsed 100%CPU
+ ==> 12!/0.91 == 526,375,384 per second
 
 */
 
