@@ -1,4 +1,5 @@
 
+#include "comb/perm-star-inv.h"
 #include "comb/perm-rev.h"
 
 #define PERM_STAR_WITH_INVERSE  // make sure inverse is computed
@@ -14,12 +15,12 @@
 #include "jjassert.h"
 
 
-//% Inverse star transposition permutations via permutations by prefix reversals.
+//% Inverse star transposition permutations
+//% via permutations by prefix reversals.
 
 //#define TIMING  // uncomment to disable printing
 
 
-
 int
 main(int argc, char **argv)
 {
@@ -27,58 +28,56 @@ main(int argc, char **argv)
     NXARG(n, "Number of elements to permute n>0");
     jjassert( n>0 );
 
-#if !defined TIMING
+    perm_star_inv P(n);
+    P.first();
+    ulong ct = 0;
+
+#if defined TIMING
+    do  { ++ct; }  while ( P.next() );
+
+#else  // TIMING
+
 #if !defined PERM_STAR_WITH_INVERSE
 #error "Need inverse star-permutations for testing."
 #endif
 
-    perm_star S(n);  S.first();
+    perm_star S(n);  S.first();  // for test
     const ulong *si = S.invdata();
-    bool dfz= true;  // whether to print dots for zeros
-    ulong ct = 0;
-#endif
 
-    perm_rev P(n);  P.first();
-    ulong *x = new ulong[n];
-    const ulong *r = P.data();
-    for (ulong k=0; k<n; ++k)  x[k] = k;
+    bool dfz= true;  // whether to print dots for zeros
+
+    const ulong *x = P.data();
     ulong i0 = 0;  // position of element zero
     do
     {
-        ulong i1 = r[0];
-        swap2(x[i0], x[i1]);
-
-#if !defined TIMING
         ++ct;
         cout << setw(4) << ct << ":";
-        print_perm("    ", x, n, dfz);
-        cout << "    " << "(" << i0 << ", " << i1 << ")";
         P.print("    ", dfz);
-        cout << endl;
-        for (ulong j=0; j<n; ++j)  jjassert( si[j]==x[j] );
-        S.next();
-#endif
-
+        ulong i1 = P.swp0();
+        cout << "    " << "(" << i0 << ", " << i1 << ")";
         i0 = i1;
+        cout << endl;
+        for (ulong j=0; j<n; ++j)  jjassert( si[j]==x[j] );  // test
+        S.next();
     }
     while ( P.next() );
-#if !defined TIMING
-    cout << " ct=" << ct << endl;
-#endif
 
-    delete [] x;
+#endif  // TIMING
+    cout << " ct=" << ct << endl;
 
     return 0;
 }
 // -------------------------
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
-% time ./bin 12
+ time ./bin 12
 arg 1: 12 == n  [Number of elements to permute n>0]  default=4
-./bin 12  3.10s user 0.00s system 99% cpu 3.113 total
- ==> 12!/3.10 == 154,516,645 per second
+ ct=479001600
+1.18user 0.00system 0:01.18elapsed 100%CPU
+ ==> 12!/1.10 == 435,456,000 per second
 
 */
 
