@@ -1,14 +1,17 @@
 
 #include "comb/perm-star-swaps.h"
 
-#include "perm/permq.h"
+//#include "perm/permq.h"
 #include "comb/comb-print.h"
 
 #include "fxttypes.h"
 #include "nextarg.h"  // NXARG()
 #include "fxtio.h"
 
-//% Generate swaps for permutations in star-transpostion order.
+//% Permutations in star-transposition order (a Gray code).
+//% Compute swaps only.
+//% Algorithm by Gideon Ehrlich, as given by Knuth,
+//%  TAOCP 4A/1, Algorithm E "Ehrlich swaps", p.337.
 //% Cf. OEIS sequences A123400 and A159880.
 
 //#define TIMING  // uncomment to disable printing
@@ -30,7 +33,8 @@ main(int argc, char **argv)
     cout << "PERM_STAR_SWAPS_FIXARRAYS is defined." << endl;
 #endif
     while ( P.next() ) {;}
-
+    ulong dummy;  P.get_swap(dummy, dummy);
+    if ( dummy > n )  { return 1; }  // never
 #else
 
     bool dfz= true;  // whether to print dots for zeros
@@ -44,12 +48,14 @@ main(int argc, char **argv)
         cout << setw(4) << ct << ":";
         ulong sw1, sw2;
         P.get_swap(sw1, sw2);
-        swap2( x[sw1], x[sw2]);  // update permutation
+        swap2( x[sw1], x[sw2] );  // update permutation
         print_perm("    ", x, n, dfz);
+//        print_perm("  b[]: ", P.b_, n, dfz);
 
+        // right element in swap gives OEIS sequence A123400
         cout << "     (" << sw1 << ", " << sw2 << ") ";
 
-        swap2( xi[x[sw1]], xi[x[sw2]]);  // update inverse permutation
+        swap2( xi[x[sw1]], xi[x[sw2]] );  // update inverse permutation
         print_perm("    ", xi, n, dfz);
 
         cout << endl;
@@ -76,18 +82,19 @@ A159880:
 */
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
-% time ./bin 12
+time ./bin 12
 arg 1: 12 == n  [Number of elements to permute]  default=4
 PERM_STAR_SWAPS_FIXARRAYS is defined.
-./bin 12  2.52s user 0.00s system 99% cpu 2.533 total
- ==> 12!/2.52 == 190,080,000 per second
+0.60user 0.00system 0:00.60elapsed 100%CPU
+ ==> 12!/0.60 == 798,336,000 per second
 
-% time ./bin 12
+time ./bin 12
 arg 1: 12 == n  [Number of elements to permute]  default=4
-./bin 12  3.18s user 0.00s system 99% cpu 3.188 total
- ==> 12!/3.18 == 150,629,433 per second
+0.64user 0.00system 0:00.64elapsed 100%CPU
+ ==> 12!/0.64 == 748,440,000 per second
 
 */
 
