@@ -12,12 +12,13 @@
 #include "aux0/swap.h"
 #include "fxttypes.h"
 
-//#include "perm/permq.h"  // is_involution(), is_connected()
+//#include "perm/permq.h"  // perm_is_involution(), perm_is_connected(), etc.
 //#include "jjassert.h"
 
 #include "nextarg.h"  // NXARG()
 
-//% Permutations with restricted prefixes
+//% Permutations with restricted prefixes.
+//% Knuth's "Algorithm X", section 7.2.1.2, p.334 in vol.4A1 of TAOCP.
 
 // Cf. comb/mixedradix-prefix-cond-demo.cc for mixed radix numbers with restricted prefixes.
 
@@ -48,11 +49,11 @@ void visit(const ulong *a, ulong n, ulong ct)
     print_cycles("    ", z, n);
 
 //    ulong z[n];  for (ulong k=0; k<n; ++k)  z[k] = a[k+1]-1;
-//    if ( is_cyclic(z, n) )  cout << "  Cyc";
-//    if ( is_connected(z, n) )  cout << "  Ind";
-//    if ( is_involution(z, n) )  cout << "  Inv";
-//    if ( is_updown_permutation(z, n) )  cout << "  UpD";
-//    if ( is_derangement(z, n) )  cout << "  Der";
+//    if ( perm_is_cyclic(z, n) )  cout << "  Cyc";
+//    if ( perm_is_connected(z, n) )  cout << "  Ind";
+//    if ( perm_is_involution(z, n) )  cout << "  Inv";
+//    if ( perm_is_updown_permutation(z, n) )  cout << "  UpD";
+//    if ( perm_is_derangement(z, n) )  cout << "  Der";
 
     cout << endl;
 }
@@ -306,63 +307,77 @@ main(int argc, char **argv)
 //          "\n      (8: playground)"
           );
 
-    perm1_prefix_cond *perm;
+    perm1_prefix_cond *P;
     switch ( c )
     {
     case 0:
         cout << "All permutations:" << endl;
-        perm = new perm1_prefix_cond(n, cond_0, visit);  break;
+        P = new perm1_prefix_cond(n, cond_0);  break;
     case 1:
         cout << "Involutions (self-inverse permutations):" << endl;
-        perm = new perm1_prefix_cond(n, cond_invol, visit);  break;
+        P = new perm1_prefix_cond(n, cond_invol);  break;
     case 2:
         cout << "Up-down permutations:" << endl;
-        perm = new perm1_prefix_cond(n, cond_updown, visit);  break;
+        P = new perm1_prefix_cond(n, cond_updown);  break;
     case 3:
         cout << "Connected (indecomposable) permutations:" << endl;
-        perm = new perm1_prefix_cond(n, cond_indecomp, visit);  break;
+        P = new perm1_prefix_cond(n, cond_indecomp);  break;
     case 4:
         cout << "Derangements:" << endl;
-        perm = new perm1_prefix_cond(n, cond_derange, visit);  break;
+        P = new perm1_prefix_cond(n, cond_derange);  break;
     case 5:
         cout << "No [x,x+1]:" << endl;
-        perm = new perm1_prefix_cond(n, cond_xx1, visit);  break;
+        P = new perm1_prefix_cond(n, cond_xx1);  break;
     case 6:
         cout << "Distance <=2 :" << endl;
-        perm = new perm1_prefix_cond(n, cond_dist, visit);  break;
+        P = new perm1_prefix_cond(n, cond_dist);  break;
 
     case 7:
         cout << "Playground:" << endl;
-        perm = new perm1_prefix_cond(n, cond_dist_set, visit);  break;
+        P = new perm1_prefix_cond(n, cond_dist_set);  break;
     case 8:
         cout << "Playground:" << endl;
-        perm = new perm1_prefix_cond(n, cond_gt_k2, visit);  break;
+        P = new perm1_prefix_cond(n, cond_gt_k2);  break;
 
     case 10:
         cout << "Playground:" << endl;
-        perm = new perm1_prefix_cond(n, cond_cyc_dist, visit);  break;
+        P = new perm1_prefix_cond(n, cond_cyc_dist);  break;
 
     case 11:
         cout << "Canonical Gray cycles:" << endl;
-        perm = new perm1_prefix_cond(n, cond_gray, visit);  break;
+        P = new perm1_prefix_cond(n, cond_gray);  break;
 
     case 12:
         cout << "Ascends and descends of length at least 2:" << endl;
-        perm = new perm1_prefix_cond(n, cond_asc_desc_geq_2, visit);  break;
+        P = new perm1_prefix_cond(n, cond_asc_desc_geq_2);  break;
 
     case 13:
         cout << "Irreducible involutions:" << endl;
-        perm = new perm1_prefix_cond(n, cond_invol_irred, visit);  break;
+        P = new perm1_prefix_cond(n, cond_invol_irred);  break;
 
     default:
         cout << "Error!" << endl;
         return 1;
     }
 
-    ulong ct = perm->all();
+    ulong ct = 0;
+    if ( P->first() )
+    {
+#if ! defined TIMING
+        const ulong * x = P->data1();
+#endif
+        do
+        {
+            ++ct;
+#if ! defined TIMING
+            visit( x, n, ct );
+#endif
+        }
+        while ( P->next() );
+    }
     cout << " ct=" << ct << endl;
 
-    delete perm;
+    delete P;
     delete [] z;
     delete [] fc;
 
@@ -371,6 +386,46 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
+
+ time ./bin 12 0  ## all permutations (best case)
+arg 1: 12 == n  [Permutations of {1, 2, ..., n}]  default=5
+arg 2: 0 == c  [Condition function:
+      (0: empty), (1: involutions),
+      (2: up-down), (3: indecomposable),
+      (4: derangement), (5: no [x,x+1])
+      (6: distance condition)]  default=4
+All permutations:
+ ct=479001600
+8.17user 0.00system 0:08.17elapsed 100%CPU
+ ==> 479001600/8.17 == 58,629,326 per second
+
+time ./bin 12 4 ## derangements
+arg 1: 12 == n  [Permutations of {1, 2, ..., n}]  default=5
+arg 2: 4 == c  [Condition function:
+      (0: empty), (1: involutions),
+      (2: up-down), (3: indecomposable),
+      (4: derangement), (5: no [x,x+1])
+      (6: distance condition)]  default=4
+Derangements:
+ ct=176214841
+3.77user 0.00system 0:03.78elapsed 99%CPU
+ ==> 176214841/3.77 == 46,741,337 per second
+
+time ./bin 14 1  ## involutions
+arg 1: 14 == n  [Permutations of {1, 2, ..., n}]  default=5
+arg 2: 1 == c  [Condition function:
+      (0: empty), (1: involutions),
+      (2: up-down), (3: indecomposable),
+      (4: derangement), (5: no [x,x+1])
+      (6: distance condition)]  default=4
+Involutions (self-inverse permutations):
+ ct=2390480
+4.02user 0.00system 0:04.02elapsed 100%CPU
+ ==> 2390480/4.02 == 594,646 per second
+
+
 Timing: (AMD Phenom II X4 945 3000MHz)
 
  time ./bin 12 0  ## all permutations (best case)
