@@ -1,9 +1,9 @@
 
 #include "comb/setpart-rgs-gray.h"
-// demo-include "comb/print-setpart.cc"
-
 // demo-include "comb/setpart-rgs-gray.cc"
 
+#include "comb/is-noncrossing-setpart-rgs.h"
+
 #include "jjassert.h"
 #include "fxtio.h"
 #include "fxttypes.h"
@@ -36,13 +36,16 @@ main(int argc, char **argv)
 #if defined TIMING
     do  { ++ct; }  while ( P.next() );
 #else  // TIMING
+
     do
     {
+//        if ( ! is_noncrossing_setpart_rgs( P.data(), n) )  continue;
 //        if ( px && (P.m_[n]!=px) )  continue;
         ++ct;
         cout << setw(4) << ct << ":";
         P.print("  ", true);
         P.print_set("    ");
+//        if ( ! is_noncrossing_setpart_rgs( P.data(), n) )  cout << "  Crossing";
         cout << endl;
 
         jjassert( P.OK() );
