@@ -57,13 +57,14 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
  time ./bin 28
 arg 1: 28 == n  [Size of the set]  default=5
 arg 2: 0 == zq  [Option: alternative order]  default=0
-./bin 28  13.08s user 0.03s system 99% cpu 13.122 total
- ==> 2^28/13.08 == 20,522,588 per second
+1.99user 0.00system 0:01.99elapsed 100%CPU
+ ==> 2^28/1.99 == 134,892,188 per second
 
 */
 
