@@ -78,38 +78,26 @@ main(int argc, char **argv)
 
 /*
 
-Timing:
+Timing: (Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz)
 
- time ./bin 30 0
-arg 1: 30 == n  [Size of the set]  default=5
+GCC 12.2.0
+
+time ./bin 30 0
+arg 1: 30 == n  [Size of the set (n>=1)]  default=6
 arg 2: 0 == dir  [Benchmark: whether to go backwards]  default=0
 forward:
-./bin 30 0  3.94s user 0.00s system 100% cpu 3.943 total
- ==> 2^30/3.94 == 272,523,305 per second
+ct=1073741823
+1.19user 0.00system 0:01.19elapsed 100%CPU (0avgtext+0avgdata 3444maxresident)k
+ ==> 2^30/1.19 == 902,304,053 per second
 
- time ./bin 30 0
-arg 1: 30 == n  [Size of the set]  default=5
-SUBSET_LEX_MAX_ARRAY_LEN is defined.
-arg 2: 0 == dir  [Benchmark: whether to go backwards]  default=0
-forward:
-./bin 30 0  3.92s user 0.00s system 100% cpu 3.920 total
- ==> 2^30/3.92 == 273,913,730 per second
-
-
- time ./bin 30 1
-arg 1: 30 == n  [Size of the set]  default=5
+time ./bin 30 1
+arg 1: 30 == n  [Size of the set (n>=1)]  default=6
 arg 2: 1 == dir  [Benchmark: whether to go backwards]  default=0
 backward:
-./bin 30 1  6.81s user 0.03s system 99% cpu 6.842 total
- ==> 2^30/6.81 == 157,671,339 per second
+ct=1073741823
+1.63user 0.00system 0:01.63elapsed 100%CPU (0avgtext+0avgdata 3448maxresident)k
+  ==> 2^30/1.63 == 658,737,315 per second
 
- time ./bin 30 1
-arg 1: 30 == n  [Size of the set]  default=5
-SUBSET_LEX_MAX_ARRAY_LEN is defined.
-arg 2: 1 == dir  [Benchmark: whether to go backwards]  default=0
-backward:
-./bin 30 1  5.54s user 0.00s system 99% cpu 5.545 total
- ==> 2^30/5.54 == 193,816,213 per second
 */
 
 /*
