@@ -7,7 +7,7 @@
 //#include "aux0/rand-idx.h"
 //#include "perm/permrand.h"
 
-#include "perm/permq.h"
+#include "perm/permq.h"  // perm_is_connected()
 #include "comb/comb-print.h"
 
 #include "fxtio.h"
@@ -44,7 +44,7 @@ main(int argc, char **argv)
         cout << endl;
 #endif  // TIMING
 //        jjassert( is_valid_permutation(f, n) );
-        jjassert( is_connected(f, n) );
+        jjassert( perm_is_connected(f, n) );
     }
 
     delete [] f;
