@@ -9,7 +9,7 @@
 //#include "aux0/rand-idx.h"
 //#include "perm/permrand.h"
 
-#include "perm/permq.h"
+#include "perm/permq.h"  // perm_is_valid()
 #include "comb/comb-print.h"
 
 #include "fxtio.h"
@@ -71,7 +71,7 @@ main(int argc, char **argv)
 
         cout << endl;
 #endif  // TIMING
-//        jjassert( is_valid_permutation(f, n) );
+//        jjassert( perm_is_valid(f, n) );
     }
 
     delete [] f;
