@@ -8,7 +8,7 @@
 #include "aux0/swap.h"
 #include "fxttypes.h"
 
-#include "perm/permq.h"  // is_cyclic(), ...
+#include "perm/permq.h"  // perm_is_cyclic(), ...
 #include "jjassert.h"
 
 #include "nextarg.h"  // NXARG()
@@ -29,12 +29,12 @@ void visit(const ulong *f, ulong n, ulong ct)
 //    cout << "    ";
 //    print_cycle(f, 0);
 
-    if ( is_connected(f, n) )  cout << "  Ind";
-    if ( is_updown_permutation(f, n) )  cout << "  UpD";
-    if ( is_derangement(f, n) )  cout << "  Der";  // only for n even
-//    if ( is_cyclic(f, n) )  cout << "  Cyc";
+    if ( perm_is_connected(f, n) )  cout << "  Ind";
+    if ( perm_is_updown_permutation(f, n) )  cout << "  UpD";
+    if ( perm_is_derangement(f, n) )  cout << "  Der";  // only for n even
+//    if ( perm_is_cyclic(f, n) )  cout << "  Cyc";
     cout << endl;
-    jjassert( is_involution(f, n) );
+    jjassert( perm_is_involution(f, n) );
 }
 // -------------------------
 
