@@ -3,7 +3,7 @@
 
 #include "perm/printcycles.h"
 #include "comb/comb-print.h"
-#include "perm/permq.h"
+//#include "perm/permq.h"
 
 #include "comb/fact2perm.h"
 
@@ -98,21 +98,35 @@ main(int argc, char **argv)
     {
     case 0:
         cout << "A003043, Hamiltonian paths:" << endl;
-        perm = new perm1_prefix_cond(n, cond_gray, visit);  break;
+        perm = new perm1_prefix_cond(n, cond_gray);  break;
     case 1:
         cout << "A059783, paths from vec(0) to vec(1)):" << endl;
-        perm = new perm1_prefix_cond(n, cond_gray_path, visit);  break;
+        perm = new perm1_prefix_cond(n, cond_gray_path);  break;
 
 //    case 9:
 //        cout << "Playground:" << endl;
-//        perm = new perm1_prefix_cond(n, cond_gray, visit);  break;
+//        perm = new perm1_prefix_cond(n, cond_gray);  break;
 
     default:
         cout << "Error!" << endl;
         return 1;
     }
 
-    ulong ct = perm->all();
+    ulong ct = 0;
+    if ( perm->first() )
+    {
+#if ! defined TIMING
+        const ulong * x = perm->data1();
+#endif
+        do
+        {
+            ++ct;
+#if ! defined TIMING
+            visit( x, n, ct );
+#endif
+        }
+        while ( perm->next() );
+    }
     cout << " ct=" << ct << endl;
 
     if ( c==1 )  // for cond_gray_path()
