@@ -36,7 +36,7 @@ main(int argc, char **argv)
 
         ++ct;
 
-#ifndef TIMING
+#if !defined TIMING
         cout << setw(3) << ct << ": ";
         for (ulong k=0; k<m; ++k)  cout << " " << x[k];
         cout << endl;
