@@ -1,7 +1,7 @@
 #if !defined  HAVE_CSWAP_H__
 #define       HAVE_CSWAP_H__
 // This file is part of the FXT library.
-// Copyright (C) 2010, 2012 Joerg Arndt
+// Copyright (C) 2010, 2012, 2023 Joerg Arndt
 // License: GNU General Public License version 3 or later,
 // see the file COPYING.txt in the main directory.
 
@@ -15,7 +15,7 @@ static inline void cswap_lt(ulong &a, ulong &b)
 // NOTE: Whether this routine is faster depends both
 // on the machine used and the surrounding code.
 {
-#ifdef BITS_USE_ASM_AMD64
+#if defined BITS_USE_ASM_AMD64
     asm volatile("movq %0, %%r15 \n"   // t=a
                  "cmpq %0, %1 \n"      // cmp a, b
                  "cmovae %1, %0 \n"    // cond a=b
