@@ -1,7 +1,7 @@
 #if !defined HAVE_COMB_ALL_H__
 #define      HAVE_COMB_ALL_H__
 // This file is part of the FXT library.
-// Copyright (C) 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021, 2023 Joerg Arndt
+// Copyright (C) 2010 - 2024 Joerg Arndt
 // License: GNU General Public License version 3 or later,
 // see the file COPYING.txt in the main directory.
 
@@ -9,14 +9,18 @@
 //: Combinatorics
 
 //: subsets:
-#include "comb/subset-gray.h"
-#include "comb/subset-gray-delta.h"
 #include "comb/subset-lex.h"
+#include "comb/subset-gray.h"
+#include "comb/subset-sl-gray.h"
+#include "comb/subset-gray-delta.h"
 #include "comb/ksubset-lex.h"
 #include "comb/subset-deltalex.h"
 #include "comb/subset-debruijn.h"
 #include "comb/ksubset-gray.h"
 #include "comb/ksubset-twoclose.h"
+#include "comb/ksubset-twoclose-rec.h"
+#include "comb/ksubset-twoclose-list.h"
+#include "comb/ksubset-twoclose-list-rec.h"
 #include "comb/ksubset-rec.h"
 #include "comb/binary-sl-gray.h"
 #include "comb/binary-rot.h"
@@ -209,11 +213,13 @@
 #include "comb/setpart-rgs-gray.h"
 #include "comb/setpart-rgs-subset-lex.h"
 #include "comb/setpart-p-rgs-lex.h"
-#include "comb/setpart-rgs-fixed-content.h"
+#include "comb/setpart-rgs-fixed-content-vec.h"
 #include "comb/setpart-ck-rgs.h"
 #include "comb/setpart-zero-map-rgs.h"
 #include "comb/setpart-s-zero-map-rgs.h"
 #include "comb/setpart-ccf-rgs-lex.h"
+#include "comb/setpart-noncrossing-rgs.h"
+#include "comb/setpart-noncrossing-ll.h"
 // closely related RGS:
 #include "comb/rgs-maxincr.h"
 #include "comb/rgs-fincr.h"
@@ -269,11 +275,12 @@
 #include "comb/mixedradix-gslex-alt.h"
 #include "comb/mixedradix-endo.h"
 #include "comb/mixedradix-endo-gray.h"
-#include "comb/mixedradix-sod-lex.h"
 #include "comb/mixedradix-naf.h"
 #include "comb/mixedradix-naf-gray.h"
 #include "comb/mixedradix-naf-subset-lex.h"
 #include "comb/mixedradix-prefix-cond.h"
+#include "comb/mixedradix-fixed-content.h"
+#include "comb/mixedradix-fixed-content-lex.h"
 #include "comb/skew-binary.h"
 //
 #include "comb/mixedradix-subset-lex-rank.h"
@@ -311,13 +318,16 @@
 #include "comb/perm-pref.h"
 #include "comb/perm-star.h"
 #include "comb/perm-star-swaps.h"
+#include "comb/perm-star-inv.h"
 #include "comb/perm1-prefix-cond.h"
+#include "comb/perm1-topsort.h"
 #include "comb/perm-rev.h"
 #include "comb/perm-st.h"
 #include "comb/perm-st-pref.h"
 #include "comb/perm-st-gray.h"
 #include "comb/perm-derange.h"
 #include "comb/perm-involution.h"
+#include "comb/cyclic-perm-gray.h"
 #include "comb/involution-zero-map-rgs.h"
 // auxiliary routines:
 #include "comb/is-stack-sortable.h"
@@ -325,9 +335,9 @@
 
 //: signed permutations:
 #include "comb/signed-perm.h"
+#include "comb/signed-perm-gray.h"
 
 //: conversions between permutations and factorial numbers:
-#include "comb/cyclic-perm.h"
 #include "comb/fact2num2perm.h"
 #include "comb/fact2perm.h"
 #include "comb/big-fact2perm.h"
@@ -377,6 +387,7 @@
 //: standard Young tableaux:
 #include "comb/young-tab-rgs.h"
 #include "comb/young-tab-rgs-subset-lex.h"
+#include "comb/young-tab-fixed-shape.h"
 // auxiliary routines:
 #include "comb/young-tab-rgs-descents.h"
 #include "comb/is-young-tab-rgs.h"
@@ -388,8 +399,8 @@
 #include "comb/smooth-rfact-rgs.h"
 
 
-//: unimodal words (RGS):
-#include "comb/weakly-unimodal-rgs-lex.h"
+//: unimodal maps:
+#include "comb/weakly-unimodal-map-lex.h"
 // auxiliary routines:
 #include "comb/is-unimodal.h"
 
