@@ -153,17 +153,17 @@ public:
     void print(const char *bla, bool dfz=false)  const
     { print_vec(bla, a_, n_+1, dfz); }
 
-    void print_aa()  const  // ASCII art
+    void print_vert_aa()  const  // ASCII art
     {
 #if defined CATALAN_PATH_LEX_NO_FLAT_STEPS
-        print_catalan_path_aa(data(), n_, true);
+        print_catalan_path_vert_aa(data(), n_, true);
 #else
-        print_catalan_path_aa(data(), n_, false);
+        print_catalan_path_vert_aa(data(), n_, false);
 #endif
     }
 
     void print_horiz_aa()  const  // ASCII art
-    { catalan_path_print_horiz_aa(data(), n_); }
+    { print_catalan_path_horiz_aa(data(), n_); }
 
     bool OK()  const
     { return is_catalan_path( data(), n_ ); }
