@@ -11,6 +11,7 @@
 
 class dyck_pref
 // k-ary Dyck words via prefix shifts.
+// Representation as delta set.
 // Algorithm "coolkat" as given (left in figure "Algorithms 1") in
 //   Stephane Durocher, Pak Ching Li, Debajyoti Mondal, Aaron Williams:
 //   "Ranking and Loopless Generation of k-ary Dyck Words in Cool-lex Order",
@@ -57,7 +58,7 @@ public:
         for (ulong j=n_+1; j<=len_; ++j)  B_[j] = 0;
     }
 
-    const ulong * data()  const  { return B_+1; }
+    const ulong * data()  const  { return B_ + 1; }
 
     bool next()
     {
@@ -68,7 +69,7 @@ public:
         {
             if ( x_-2 == k_*(y_-2) )
             {
-                while ( 0==B_[x_] )  ++x_;
+                while ( 0==B_[x_] )  { ++x_; }
             }
             else
             {
