@@ -23,7 +23,7 @@ class ordered_tree_branches
 // branch heights (height of base of branch, array b[]) are such that
 // b[j] < a[j-1] + b[j-1] for j>=2 (and b[1]=0).
 {
-public:
+private:
 #if !defined ORDERED_TREE_BRANCHES_FIXARRAYS
     ulong *a_;  // branch lengths (limbs): a composition a[1] + a[2] + ... + a[m] = n
     ulong *b_;  // branch heights (absolute, above root)
@@ -119,8 +119,8 @@ public:
         print_vec(bla, height_data(), num_branches(), false);
     }
 
+    // comb/ordered-tree-branches.h:
     void print_level_seq(const char *bla)  const;
-
     void print_aa()  const;  // ASCII art
 };
 // -------------------------
