@@ -10,7 +10,7 @@
 
 
 // use arrays instead of pointers:
-#define PERM_HEAP2_SWAPS_FIXARRAYS  // speedup
+//#define PERM_HEAP2_SWAPS_FIXARRAYS  // default off, slowdown
 
 
 class perm_heap2_swaps
@@ -84,7 +84,7 @@ public:
             if ( j==n_-1 )  return  n_;
 
             ulong k = j+1;
-            ulong x = ( k&1 ? d_[j] : 0 );
+            ulong x = ( k & 1 ? d_[j] : 0 );
             sw1_ = k;  sw2_ = x;
 
             ++d_[j];
