@@ -11,12 +11,12 @@
 
 // define to also compute inverse:
 #define PERM_STAR_WITH_INVERSE
-
-#define PERM_STAR_FIXARRAYS  // speedup
+#define PERM_STAR_FIXARRAYS
 
 class perm_star
 // Permutations in star-transposition order (a Gray code).
-// Algorithm of Gideon Ehrlich, as given by Knuth
+// Algorithm by Gideon Ehrlich, as given by Knuth,
+//  TAOCP 4A/1, Algorithm E "Ehrlich swaps", p.337.
 {
 public:
     ulong n_;    // number of elements
@@ -106,7 +106,11 @@ public:
     }
 
     ulong get_swap()  const  { return swp_; }
-    void get_swap(ulong &s1, ulong &s2)  const  { s1=0; s2=swp_; }
+    void get_swap(ulong &s1, ulong &s2)  const
+    {
+        s1=0;
+        s2=swp_;  // OEIS sequence A123400
+    }
 
 
     const ulong * data()  const  { return a_; }
