@@ -1,5 +1,5 @@
 // This file is part of the FXT library.
-// Copyright (C) 2010, 2012 Joerg Arndt
+// Copyright (C) 2010, 2012, 2023 Joerg Arndt
 // License: GNU General Public License version 3 or later,
 // see the file COPYING.txt in the main directory.
 
@@ -20,7 +20,7 @@ loc_fht_auto_convolution(double *f, ulong ldn)
 {
 //    if ( ldn<=1 )  { f[0] *= f[0]; return; }
 
-#ifdef  USE_REVBIN_CORE
+#if defined  USE_REVBIN_CORE
     fht_loc_dif2_core(f, ldn);
     fht_auto_convolution_revbin_permuted_core(f, ldn);
     fht_loc_dit2_core(f, ldn);
@@ -43,7 +43,7 @@ loc_fht_auto_convolution0(double *f, ulong ldn)
 {
 //    if ( ldn<=1 )  { f[0] *= f[0]; return; }
 
-#ifdef  ZP_USE_REVBIN_CORE
+#if defined  ZP_USE_REVBIN_CORE
     fht_loc_dif2_core(f, ldn);
     fht_auto_convolution_revbin_permuted_core(f, ldn);
     fht_loc_dit2_core(f, ldn);
